import { BrowserModule } from '@angular/platform-browser';
import { NgModule } from '@angular/core';
import {FormsModule, ReactiveFormsModule} from '@angular/forms';
import { HttpClientModule, HttpClient } from '@angular/common/http';

// NG Translate
import { TranslateModule, TranslateLoader } from '@ngx-translate/core';
import { TranslateHttpLoader } from '@ngx-translate/http-loader';

import { AppComponent } from './app.component';
import {CoreModule} from "./core/core.module";
import {SharedModule} from "./shared/shared.module";
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import {MatIcon} from "@angular/material/icon";
import {MatToolbar} from "@angular/material/toolbar";
import {MatButton, MatIconButton, MatMiniFabButton} from "@angular/material/button";
import {MatError, MatFormField, MatHint, MatLabel} from "@angular/material/form-field";
import {MatInput} from "@angular/material/input";
import {MatDrawer, MatDrawerContainer} from "@angular/material/sidenav";
import {MatMenu, MatMenuItem, MatMenuTrigger} from "@angular/material/menu";
import {
  ScriptAccountOverviewComponent
} from "./side-overviews/script-account-overview/script-account-overview.component";
import {MatActionList, MatListItem} from "@angular/material/list";
import {EditorComponent} from "./editor/editor.component";
import {MatTab, MatTabGroup, MatTabLabel} from "@angular/material/tabs";
import {ScriptAccountEditorComponent} from "./editor/script-account-editor/script-account-editor.component";
import {ModelComponentEditorComponent} from "./editor/model-component-editor/model-component-editor.component";
import {DeleteConfirmationDialogComponent} from "./delete-confirmation-dialog/delete-confirmation-dialog.component";
import {MatDialogActions, MatDialogContent, MatDialogTitle} from "@angular/material/dialog";
import {GamescriptOverviewComponent} from "./side-overviews/gamescript-overview/gamescript-overview.component";
import {MatTree, MatTreeModule} from "@angular/material/tree";
import {GamesystemEditorComponent} from "./editor/gamesystem-editor/gamesystem-editor.component";
import {
  SimpleGamesystemEditorComponent
} from "./editor/gamesystem-editor/simple-gamesystem-editor/simple-gamesystem-editor.component";
import {
  SimpleStateEditorComponent
} from "./editor/gamesystem-editor/state-editor/simple-state-editor/simple-state-editor.component";
import {
  MatCell,
  MatCellDef,
  MatColumnDef,
  MatHeaderCell,
  MatHeaderCellDef,
  MatHeaderRow, MatHeaderRowDef, MatRow, MatRowDef,
  MatTable
} from "@angular/material/table";
import {MatCheckbox} from "@angular/material/checkbox";
import {
  SimpleTransitionEditorComponent
} from "./editor/gamesystem-editor/transition-editor/simple-transition-editor/simple-transition-editor.component";
import {MatOption, MatSelect} from "@angular/material/select";
import {
  ProductGamesystemEditorComponent
} from "./editor/gamesystem-editor/product-gamesystem-editor/product-gamesystem-editor.component";
import {
  ProductTransitionEditorComponent
} from "./editor/gamesystem-editor/transition-editor/product-transition-editor/product-transition-editor.component";
import {
  ProductStateEditorComponent
} from "./editor/gamesystem-editor/state-editor/product-state-editor/product-state-editor.component";
import {MatTooltip} from "@angular/material/tooltip";
import {MatCard, MatCardActions, MatCardContent, MatCardHeader, MatCardTitle} from "@angular/material/card";
import {
    ScriptaccountActionEditorComponent
} from "./editor/gamesystem-editor/transition-editor/scriptaccount-action-editor/scriptaccount-action-editor.component";
import {
    ScriptaccountConditionEditorComponent
} from "./editor/gamesystem-editor/scriptaccount-condition-editor/scriptaccount-condition-editor.component";
import {CharacterOverviewComponent} from "./side-overviews/character-overview/character-overview.component";
import {CharacterEditorComponent} from "./editor/character-editor/character-editor.component";
import {
  MatAccordion,
  MatExpansionPanel,
  MatExpansionPanelHeader,
  MatExpansionPanelTitle
} from "@angular/material/expansion";
import {
  TemplateSpecificatorComponent
} from "./editor/gamesystem-editor/template-specificator/template-specificator.component";
import {
    StateInitialCellComponent
} from "./editor/gamesystem-editor/state-editor/simple-state-editor/state-initial-cell/state-initial-cell.component";
import {
    InventoryItemOverviewComponent
} from "./side-overviews/inventory-item-overview/inventory-item-overview.component";
import {InventoryItemEditorComponent} from "./editor/inventory-item-editor/inventory-item-editor.component";
import {
  ItemPropertyEditorComponent
} from "./editor/inventory-item-editor/item-property-editor/item-property-editor.component";

// AoT requires an exported function for factories
const httpLoaderFactory = (http: HttpClient): TranslateHttpLoader =>  new TranslateHttpLoader(http, './assets/i18n/', '.json');

@NgModule({
  declarations: [
    AppComponent,
    ScriptAccountOverviewComponent,
    EditorComponent,
    ScriptAccountEditorComponent,
    ModelComponentEditorComponent,
    DeleteConfirmationDialogComponent,
    GamescriptOverviewComponent,
    GamesystemEditorComponent,
    SimpleGamesystemEditorComponent,
    SimpleStateEditorComponent,
    SimpleTransitionEditorComponent,
    ProductTransitionEditorComponent,
    ProductStateEditorComponent,
    ProductGamesystemEditorComponent,
    ScriptaccountActionEditorComponent,
    ScriptaccountConditionEditorComponent,
    CharacterOverviewComponent,
    CharacterEditorComponent,
    TemplateSpecificatorComponent,
    StateInitialCellComponent,
    InventoryItemOverviewComponent,
    InventoryItemEditorComponent,
    ItemPropertyEditorComponent
  ],
  imports: [
    BrowserModule,
    FormsModule,
    HttpClientModule,
    CoreModule,
    SharedModule,
    TranslateModule.forRoot({
      loader: {
        provide: TranslateLoader,
        useFactory: httpLoaderFactory,
        deps: [HttpClient]
      }
    }),
    BrowserAnimationsModule,
    MatIcon,
    MatToolbar,
    MatButton,
    MatFormField,
    MatInput,
    MatDrawerContainer,
    MatDrawer,
    MatIconButton,
    MatMenuTrigger,
    MatMenu,
    MatMenuItem,
    MatListItem,
    MatActionList,
    MatTabGroup,
    MatTab,
    MatTabLabel,
    MatLabel,
    MatFormField,
    ReactiveFormsModule,
    MatError,
    MatDialogTitle,
    MatDialogContent,
    MatDialogActions,
    MatMiniFabButton,
    MatTreeModule,
    MatTable,
    MatColumnDef,
    MatHeaderCell,
    MatHeaderCellDef,
    MatCellDef,
    MatCell,
    MatHeaderRow,
    MatRow,
    MatHeaderRowDef,
    MatRowDef,
    MatCheckbox,
    MatSelect,
    MatOption,
    MatHint,
    MatTooltip,
    MatCard,
    MatCardContent,
    MatCardHeader,
    MatAccordion,
    MatExpansionPanel,
    MatExpansionPanelTitle,
    MatCardTitle,
    MatExpansionPanelHeader,
    MatCardActions,
  ],
  providers: [],
  bootstrap: [AppComponent]
})
export class AppModule {}
