import {ItemProperty} from "./ItemProperty";
import {ItemQuality} from "./ItemQuality";
import {ModelComponent} from "../ModelComponent";
import {ModelComponentType} from "../ModelComponentType";
import {ItemPropertyDescription} from "./ItemPropertyDescription";

export class Item extends ModelComponent {

  possible_qualities: ItemQuality[] = []
  itemProperties: ItemProperty[] = []

  perQualityProperties: ItemPropertyDescription[] = []

  constructor(componentName: string, componentDescription: string, type: ModelComponentType) {
    super(componentName, componentDescription, type);
    this.itemProperties.push(new ItemProperty("Weight", "Some Weights", 10))
    this.possible_qualities.push(new ItemQuality(0.25))
    this.possible_qualities.push(new ItemQuality(0.50))
    this.possible_qualities.push(new ItemQuality(0.75))
    this.possible_qualities.push(new ItemQuality(1.00))

    this.addPerQualityProperty(new ItemPropertyDescription("Price", "Price to buy item"))
  }

  removePerQualityProperty(qualityProperty: ItemPropertyDescription) {
    this.perQualityProperties = this.perQualityProperties.filter(perQualityProperty => perQualityProperty !== qualityProperty);
    this.possible_qualities.forEach(quality => {
      quality.removeQualityProperty(qualityProperty.propertyName);
    })
  }

  addPerQualityProperty(qualityProperty: ItemPropertyDescription) {
    if(this.perQualityProperties.find(property => property.propertyName === qualityProperty.propertyName) == undefined) {
      this.perQualityProperties.push(qualityProperty);
      this.possible_qualities.forEach(quality => quality.addQualityProperty(qualityProperty))
    }
  }

  editPerQualityProperty(qualityProperty: ItemPropertyDescription) {
    this.possible_qualities.forEach(quality => {
      quality.editQualityProperty(qualityProperty, this.perQualityProperties.map(property => property.propertyName))
    })
  }
}
