import {Item} from "../game-model/inventory/Item";
import {StoreComponent} from "../../../../app/storage/StoreComponent";
import {SerializeConstants} from "./SerializeConstants";
import {ItemQuality} from "../game-model/inventory/ItemQuality";
import {ItemPropertyDescription} from "../game-model/inventory/ItemPropertyDescription";
import {ItemProperty} from "../game-model/inventory/ItemProperty";

export class ItemSerializer {

  public static serializeItems(items: Item[]): StoreComponent[] {
    const storedItems: StoreComponent[] = []
    items.forEach(item => storedItems.push(this.serializeSingleItem(item)))
    return storedItems;
  }

  private static serializeSingleItem(item: Item): StoreComponent {
    const fileName = item.componentName;
    const componentType = item.type;
    const jsonString = JSON.stringify(item,(key, value) => {
      if(key === 'perQualityProperties') {
        return value;
      } else if(key == 'quality_propertes') {
        return value.map((prop: ItemProperty) => ({
          ...prop,
          propertyDescription: undefined
        }));
      }

      if(key === 'unsaved' || key === 'type') {
        return undefined;
      } else {
        return value;
      }
    }, SerializeConstants.JSON_INDENT)

    return new StoreComponent(jsonString, fileName, componentType);
  }
}
